@@ -1,10 +1,12 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::VerifyPhases; # git description: v0.009-2-g1b5cf6d
+package Dist::Zilla::Plugin::VerifyPhases; # git description: v0.010-10-g8c8a060
 # ABSTRACT: Compare data and files at different phases of the distribution build process
 # KEYWORDS: plugin distribution configuration phase verification validation
-# vim: set ts=8 sw=4 tw=78 et :
-$Dist::Zilla::Plugin::VerifyPhases::VERSION = '0.010';
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
+
+our $VERSION = '0.011';
+
 use Moose;
 with
     'Dist::Zilla::Role::BeforeBuild',
@@ -15,8 +17,7 @@ with
     'Dist::Zilla::Role::AfterBuild';
 use Moose::Util 'find_meta';
 use Digest::MD5 'md5_hex';
-use List::Util 1.33 qw(none first any);
-use List::MoreUtils 'first_index';
+use List::Util 1.33 qw(none any);
 use Term::ANSIColor 3.00 'colored';
 use namespace::autoclean;
 
@@ -27,14 +28,14 @@ my %all_files;
 sub _search_all_files
 {
     my ($self, $file) = @_;
-    my $index;
-    my $filename = first {
-        $index = first_index { $_->{object} == $file } @{ $all_files{$_} };
-        undef $index if $index == -1;
-        defined $index;
-    } keys %all_files;
 
-    return ($filename, $index);
+    for my $filename (keys %all_files)
+    {
+        foreach my $index (0.. $#{$all_files{$filename}})
+        {
+            return ($filename, $index) if $all_files{$filename}[$index]{object} == $file;
+        }
+    }
 }
 
 #sub mvp_multivalue_args { qw(skip) }
@@ -53,13 +54,14 @@ sub BUILD
 {
     my $self = shift;
     my $zilla = $self->zilla;
+    my $meta = find_meta($zilla);
 
     # no phases have been run yet, so we can effectively capture the initial
     # state of the zilla object (and determine its construction args)
     %zilla_constructor_args = map {
-        my $attr = find_meta($zilla)->find_attribute_by_name($_);
-        $attr->has_value($zilla) ? ( $_ => $attr->get_value($zilla) ) : ()
-    } qw(name version abstract main_module authors distmeta _license_class _copyright_holder _copyright_year);
+        my $attr = $meta->find_attribute_by_name($_);
+        $attr && $attr->has_value($zilla) ? ( $_ => $attr->get_value($zilla) ) : ()
+    } qw(name version release_status abstract main_module authors distmeta _license_class _copyright_holder _copyright_year),
 }
 
 # nothing to put in dump_config yet...
@@ -79,11 +81,14 @@ sub gather_files
     my $self = shift;
 
     my $zilla = $self->zilla;
-    foreach my $attr_name (qw(name version abstract main_module authors distmeta))
+    my $meta = find_meta($zilla);
+
+    foreach my $attr_name (qw(name version release_status abstract main_module authors distmeta))
     {
         next if exists $zilla_constructor_args{$attr_name};
+        my $attr = $meta->find_attribute_by_name($attr_name);
         $self->_alert($attr_name . ' has already been calculated by end of file gathering phase')
-            if find_meta($zilla)->find_attribute_by_name($attr_name)->has_value($zilla);
+            if $attr and $attr->has_value($zilla);
     }
 
     # license is created from some private attrs, which may have been provided
@@ -91,7 +96,7 @@ sub gather_files
     $self->_alert('license has already been calculated by end of file gathering phase')
         if any {
             not exists $zilla_constructor_args{$_}
-                and find_meta($zilla)->find_attribute_by_name($_)->has_value($zilla)
+                and $meta->find_attribute_by_name($_)->has_value($zilla)
         } qw(_license_class _copyright_holder _copyright_year);
 
     # all files should have been added by now. save their filenames/objects
@@ -293,7 +298,7 @@ Dist::Zilla::Plugin::VerifyPhases - Compare data and files at different phases o
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -324,6 +329,10 @@ version
 
 =item *
 
+release_status
+
+=item *
+
 abstract
 
 =item *
